==> pw-iso20022-SRU2022-9.3.4-sources.jar: com/prowidesoftware/swift/model/mx/dic/ExternalPaymentSystemDetails1.java <==

package com.prowidesoftware.swift.model.mx.dic;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.commons.lang3.builder.EqualsBuilder;
import org.apache.commons.lang3.builder.HashCodeBuilder;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;


/**
 * Information about external payment system.
 * 
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ExternalPaymentSystemDetails1", propOrder = {
    "clrPossRegrAllwdInd",
    "clrCrcts"
})
public class ExternalPaymentSystemDetails1 {

    @XmlElement(name = "ClrPossRegrAllwdInd")
    protected boolean clrPossRegrAllwdInd;
    @XmlElement(name = "ClrCrcts", required = true)
    protected List<ClearingCircuits1> clrCrcts;

    /**
     * Gets the value of the clrPossRegrAllwdInd property.
     * 
     */
    public boolean isClrPossRegrAllwdInd() {
        return clrPossRegrAllwdInd;
    }

    /**
     * Sets the value of the clrPossRegrAllwdInd property.
     * 
     */
    public ExternalPaymentSystemDetails1 setClrPossRegrAllwdInd(boolean value) {
        this.clrPossRegrAllwdInd = value;
        return this;
    }

    /**
     * Gets the value of the clrCrcts property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the clrCrcts property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getClrCrcts().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link ClearingCircuits1 }
     * 
     * 
     */
    public List<ClearingCircuits1> getClrCrcts() {
        if (clrCrcts == null) {
            clrCrcts = new ArrayList<ClearingCircuits1>();
        }
        return this.clrCrcts;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this, ToStringStyle.MULTI_LINE_STYLE);
    }

    @Override
    public boolean equals(Object that) {
        return EqualsBuilder.reflectionEquals(this, that);
    }

    @Override
    public int hashCode() {
        return HashCodeBuilder.reflectionHashCode(this);
    }

    /**
     * Adds a new item to the clrCrcts list.
     * @see #getClrCrcts()
     * 
     */
    public ExternalPaymentSystemDetails1 addClrCrcts(ClearingCircuits1 clrCrcts) {
        getClrCrcts().add(clrCrcts);
        return this;
    }

}

==> pw-iso20022-SRU2023-10.1.6-sources.jar: com/prowidesoftware/swift/model/mx/dic/ExternalPaymentSystemDetails1.java <==

package com.prowidesoftware.swift.model.mx.dic;

import java.util.ArrayList;
import java.util.List;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;
import org.apache.commons.lang3.builder.EqualsBuilder;
import org.apache.commons.lang3.builder.HashCodeBuilder;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;


/**
 * Information about external payment system.
 * 
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ExternalPaymentSystemDetails1", propOrder = {
    "clrPossRegrAllwdInd",
    "clrCrcts"
})
public class ExternalPaymentSystemDetails1 {

    @XmlElement(name = "ClrPossRegrAllwdInd")
    protected boolean clrPossRegrAllwdInd;
    @XmlElement(name = "ClrCrcts", required = true)
    protected List<ClearingCircuits1> clrCrcts;

    /**
     * Gets the value of the clrPossRegrAllwdInd property.
     * 
     */
    public boolean isClrPossRegrAllwdInd() {
        return clrPossRegrAllwdInd;
    }

    /**
     * Sets the value of the clrPossRegrAllwdInd property.
     * 
     */
    public ExternalPaymentSystemDetails1 setClrPossRegrAllwdInd(boolean value) {
        this.clrPossRegrAllwdInd = value;
        return this;
    }

    /**
     * Gets the value of the clrCrcts property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the Jakarta XML Binding object.
     * This is why there is not a {@code set} method for the clrCrcts property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getClrCrcts().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link ClearingCircuits1 }
     * 
     * 
     * @return
     *     The value of the clrCrcts property.
     */
    public List<ClearingCircuits1> getClrCrcts() {
        if (clrCrcts == null) {
            clrCrcts = new ArrayList<>();
        }
        return this.clrCrcts;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this, ToStringStyle.MULTI_LINE_STYLE);
    }

    @Override
    public boolean equals(Object that) {
        return EqualsBuilder.reflectionEquals(this, that);
    }

    @Override
    public int hashCode() {
        return HashCodeBuilder.reflectionHashCode(this);
    }

    /**
     * Adds a new item to the clrCrcts list.
     * @see #getClrCrcts()
     * 
     */
    public ExternalPaymentSystemDetails1 addClrCrcts(ClearingCircuits1 clrCrcts) {
        getClrCrcts().add(clrCrcts);
        return this;
    }

}
